@@ -11,8 +11,11 @@ describe 'mistral::db' do
         :connection     => 'sqlite:////var/lib/mistral/mistral.sqlite',
         :idle_timeout   => '<SERVICE DEFAULT>',
         :min_pool_size  => '<SERVICE DEFAULT>',
+        :max_pool_size  => '<SERVICE DEFAULT>',
         :max_retries    => '<SERVICE DEFAULT>',
         :retry_interval => '<SERVICE DEFAULT>',
+        :max_overflow   => '<SERVICE DEFAULT>',
+        :pool_timeout   => '<SERVICE DEFAULT>',
       )}
 
     end
@@ -22,9 +25,12 @@ describe 'mistral::db' do
         { :database_connection     => 'mysql+pymysql://mistral:mistral@localhost/mistral',
           :database_idle_timeout   => '3601',
           :database_min_pool_size  => '2',
+          :database_max_pool_size  => '11',
           :database_max_retries    => '11',
           :database_retry_interval => '11', 
           :database_db_max_retries => '-1',
+          :database_max_overflow   => '21', 
+          :database_pool_timeout   => '21', 
         }
       end
 
@@ -33,8 +39,11 @@ describe 'mistral::db' do
         :connection     => 'mysql+pymysql://mistral:mistral@localhost/mistral',
         :idle_timeout   => '3601',
         :min_pool_size  => '2',
+        :max_pool_size  => '11',
         :max_retries    => '11',
         :retry_interval => '11',
+        :max_overflow   => '21',
+        :pool_timeout   => '21',
       )}
     end
 
@@ -92,7 +101,7 @@ describe 'mistral::db' do
       end
 
       it 'install the proper backend package' do
-        is_expected.to contain_package('db_backend_package').with(
+        is_expected.to contain_package('python-pymysql').with(
           :ensure => 'present',
           :name   => 'python-pymysql',
           :tag    => ['openstack'],
@@ -107,7 +116,7 @@ describe 'mistral::db' do
       end
 
       it 'install the proper backend package' do
-        is_expected.to contain_package('db_backend_package').with(
+        is_expected.to contain_package('python-pysqlite2').with(
           :ensure => 'present',
           :name   => 'python-pysqlite2',
           :tag    => ['openstack'],
@@ -132,7 +141,6 @@ describe 'mistral::db' do
         { :database_connection => 'mysql+pymysql://mistral:mistral@localhost/mistral', }
       end
 
-      it { is_expected.not_to contain_package('db_backend_package') }
     end
   end
 
